/*
* Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
*
* This file is part of NRAO Workspaces.
*
* Workspaces is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* Workspaces is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */

package main

import (
	_ "embed"
	"flag"
	"log"
	"os"
	"ssa/spelunker/pkg/db"
	"ssa/spelunker/pkg/helpers"
	"ssa/spelunker/pkg/properties"
)

// version set executable version based on latest project git tag. Uses go generation and file embedding
// //go:generate sh get_version.sh
// //go:embed version.txt
var version string

func main() {
	// Store argument values in these
	var capoProfile string
	var wfId int

	flag.StringVar(&capoProfile, "profile", os.Getenv("CAPO_PROFILE"), "[Optional] The CAPO profile to use, defaults to CAPO_PROFILE env variable")
	flag.IntVar(&wfId, "id", -1, "[Required] The Workspaces or Archive ID for the workflow")
	v := flag.Bool("v", false, "Display the version of this utility")
	flag.Parse()

	if *v {
		//TODO: fix version system for containers
		log.Println("2.8.8.dev1")
		os.Exit(0)
	}

	if wfId < 0 {
		log.Print("Must specify a Workspaces or Archive workflow ID!\n")
		flag.Usage()
		os.Exit(1)
	}

	if len(capoProfile) <= 0 {
		log.Print("There is no CAPO profile value. Specify the profile or ensure the CAPO_PROFILE environment variable is set\n")
		flag.Usage()
		os.Exit(1)
	}

	DB, err := db.GetConnection(capoProfile)
	helpers.CheckError(err)

	var resultsDir string
	resultsDir, err = properties.GetArgument(properties.ResultsDir, wfId, DB)
	helpers.CheckError(err)

	println(resultsDir)
}
