# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""Config file for Pytest, where directory-wide fixtures are defined"""
import json
from copy import copy
from pathlib import Path

import pytest
from casa_envoy.schema import AbstractTextFile


@pytest.fixture
def rootDirectory() -> str:
    return "/tmp/workspaces_tmp"


@pytest.fixture
def processingDirectory() -> str:
    return "tmpiox5trbp"


@pytest.fixture
def parent_path() -> Path:
    return Path("I/am/a/path")


@pytest.fixture
def cal_metadata_content(resource_path_root: Path) -> dict:
    return json.loads(Path(f"{resource_path_root}/input_files/test.json").read_text())


@pytest.fixture
def img_metadata_content(resource_path_root: Path) -> dict:
    return json.loads(Path(f"{resource_path_root}/input_files/image-metadata.json").read_text())


@pytest.fixture
def alma_metadata_content(resource_path_root: Path) -> dict:
    return json.loads(Path(f"{resource_path_root}/input_files/alma-restore.json").read_text())


@pytest.fixture
def cal_settings(rootDirectory: str, processingDirectory: str, parent_path: Path, resource_path_root: Path) -> dict:
    return {
        "useCasa": False,
        "homeForReprocessing": "/home/casa/packages/pipeline/current",
        "rootDirectory": rootDirectory,
        "processingDirectory": processingDirectory,
        "metadata": str(resource_path_root / "input_files/test.json"),
        "ppr": str(resource_path_root / "input_files/PPR.xml"),
        "product_type": "standard-cal",
        "parent_path": parent_path,
    }


@pytest.fixture
def img_settings(parent_path: Path, resource_path_root: Path) -> dict:
    """Use different rootDirectory and processingDirectory to match contents of
    input_files/image-metadata.json, input_files/cube-metadata.json, and input_files/cmsimage-PPR.xml.
    """
    return {
        "useCasa": False,
        "homeForReprocessing": "/home/casa/packages/pipeline/current",
        "rootDirectory": "/lustre/aoc/cluster/pipeline/docker/workspaces/spool",
        "processingDirectory": "tmpo1ca1pp_",
        "metadata": str(resource_path_root / "input_files/image-metadata.json"),
        "ppr": str(resource_path_root / "input_files/cmsimage-PPR.xml"),
        "product_type": "standard-img",
        "parent_path": parent_path,
    }


@pytest.fixture
def restore_settings_sans_ppr(
    rootDirectory: str, processingDirectory: str, parent_path: Path, resource_path_root: Path
) -> dict:
    return {
        "useCasa": False,
        "homeForReprocessing": "/home/casa/packages/pipeline/current",
        "rootDirectory": rootDirectory,
        "processingDirectory": processingDirectory,
        "metadata": str(resource_path_root / "input_files/restore.json"),
        "ppr": None,
        "product_type": "restore",
        "parent_path": parent_path,
        "piperestorescript_path": Path("path/to/casa_piperestorescript.py"),
    }


@pytest.fixture
def restore_settings_with_ppr(restore_settings_sans_ppr: dict, resource_path_root: Path) -> dict:
    restore_settings_with_ppr_dict = copy(restore_settings_sans_ppr)
    restore_settings_with_ppr_dict["ppr"] = str(resource_path_root / "input_files/restore-PPR.xml")
    return restore_settings_with_ppr_dict


@pytest.fixture
def test_restore_metadata(resource_path_root: Path) -> AbstractTextFile:
    path = resource_path_root / "input_files/restore.json"
    return AbstractTextFile(str(path), content=path.read_text())
