#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
import logging
import shutil
import subprocess
import sys
from typing import Dict

import os

import pathlib

import tarfile

import glob

from conveyor.interfaces import ConveyorIF


"""
Cache VLASS weblogs (and maybe other VLASS-y things) for viewing in the manager
"""


class VlassConveyor(ConveyorIF):
    def __init__(self, settings: Dict[str, str], action: str):
        self.logger = logging.getLogger("conveyor")
        self.settings = settings
        self.action = action

    def cache_vlass_weblog(self):
        """
        VLASS weblogs need to be cached on Accept & Archive

        :return:
        """
        self.logger.info("Caching VLASS Weblog!")
        weblog_location = self.settings["vlass_weblog_cache_area"] + "/" + self.settings["vlass_relative_path"]

        # make new cache directory with name matching workspaces parent directory and unzip weblog into it
        os.makedirs(weblog_location)
        location_path = self.settings["vlass_destination_dir"] + "/products"
        if pathlib.Path(location_path + "/weblog.tgz").exists():
            tar = tarfile.open(location_path + "/weblog.tgz")
            # extract to cache area
            tar.extractall(path=weblog_location)
            subprocess.run(["chmod", "-R", "+rx", weblog_location])
            # extract in place
            tar.extractall(path=location_path)
            tar.close()
        elif self._get_pipeline_dir():
            self.logger.info("WARNING! No weblog.tgz, copying pipeline directory instead.")

            pipeline_dir = glob.glob(location_path + "/pipeline-*")[0]
            shutil.copytree(pipeline_dir, weblog_location)
        else:
            self.logger.error("ERROR: Neither weblog directory or tar file found! Exiting.")
            sys.exit(1)

    def _get_pipeline_dir(self) -> bool:
        if not glob.glob(self.settings["vlass_destination_dir"] + "/products/pipeline-*"):
            return False
        return True

    def convey(self):
        self.logger.info(f"Running {self.action} caching!")
        self.cache_vlass_weblog()
