from typing import NamedTuple


class Query(NamedTuple):
    """
    NamedTuple that contains query structure for metrics queries
    """

    select: str
    from_clause: str
    where: str
    conditionals: list


CAPABILITY_EXECUTIONS = Query(
    "SELECT count(*)",
    "FROM capability_execution_metrics",
    "WHERE cap_name = %(capability_name)s",
    ["AND execution_created between %(beginning)s and %(end)s"],
)
DOWNLOAD_VOLUME = Query(
    "SELECT sum(datasize)",
    "FROM ws_download_metrics",
    "WHERE state = 'Complete'",
    [
        "AND request_id = %(request_id)s GROUP BY request_id",
        "AND execution_created between %(beginning)s and %(end)s",
    ],
)
OPERATIONS = Query(
    """SELECT
   cv.capability_request_id as requestId,
   external_name as dataset,
   cv.capability_name as capability,
   eb.band_code as band,
   mjd_to_timestamp(eb.starttime) as dateObs,
   cr.updated_at as dateArchived,
   science_products.is_srdp as srdpStatus,
   cr.stage_1_reviewer as stage1Reviewer,
   cr.stage_2_reviewer as stage2Reviewer""",
    """FROM science_products
            JOIN capability_versions cv ON CASE
                WHEN science_product_locator = cv.parameters->>'product_locator' then 1
                WHEN external_name = cv.parameters->>'sdmId' then 1
                ELSE 0 end = 1
            JOIN execution_blocks eb ON science_products.science_product_locator = eb.science_product_locator
            JOIN capability_requests cr ON cv.capability_request_id = cr.capability_request_id""",
    "WHERE cr.ingested = True",
    [
        """AND updated_at between %(beginning)s and %(end)s
           GROUP BY cv.capability_request_id, external_name, 
           cv.capability_name, eb.band_code, mjd_to_timestamp(eb.starttime), 
           cr.updated_at, science_products.is_srdp, cr.stage_1_reviewer, cr.stage_2_reviewer"""
    ]
)
# OPERATIONS_COUNT = Query(
#     "SELECT COUNT(*)",
#     """FROM science_products
#             JOIN capability_versions cv ON CASE
#                 WHEN science_product_locator = cv.parameters->>'product_locator' then 1
#                 WHEN external_name = cv.parameters->>'sdmId' then 1
#                 ELSE 0 end = 1
#             JOIN execution_blocks eb on science_products.science_product_locator = eb.science_product_locator
#             JOIN capability_requests cr on cv.capability_request_id = cr.capability_request_id""",
#     "WHERE cr.ingested = True",
#     ["AND updated_at between %(beginning)s and %(end)s"],
# )
