#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
""" Conveniences for wresting detailed info from the archive MDDB """

import logging
import sys

import psycopg2 as pg
from pycapo import CapoConfig
from sqlalchemy.engine import Connection

# pylint: disable=E0401, E0402


logger = logging.getLogger("aat_wrest")
logger.setLevel(logging.INFO)
logger.addHandler(logging.StreamHandler(sys.stdout))

PENDULUM_FORMAT = "YYYY-MM-DDTHH:mm:ss"
TIME_ZONE = "UTC"


class MDDBConnector:
    """Use this connection to interrogate this science product locator"""

    def __init__(self):
        self.connection = self._connect_to_mddb()

    @staticmethod
    def _connect_to_mddb() -> Connection:
        """
        Establish a DB connection

        :return:
        """
        settings = CapoConfig().settings("metadataDatabase")

        host_slash_db = settings["jdbcUrl"][len("jdbc:postgresql://") :]
        host, dbname = host_slash_db.split("/")
        port = 5432
        if ":" in host:
            host, port = host.split(":")
        try:
            conn = pg.connect(
                host=host,
                port=port,
                database=dbname,
                user=settings.jdbcUsername,
                password=settings.jdbcPassword,
            )
            return conn
        except Exception as exc:
            logger.error(f"Unable to connect to database: {exc}")
            raise exc

    def cursor(self):
        return self.connection.cursor()

    def close(self):
        self.connection.close()
