# Workspaces Workflow Monitor

Reads in an HTCondor log file and parses the relevant data from it, splitting it into events and formatting those into messages that are sent to the `workspaces.workflow-service.workflow-status` RabbitMQ exchange. Also input is a workflow request ID that is sent alongside the event data.

```
usage: wf_monitor [-h] [-P PROFILE] log_path workflow_request_id is_dag

Workspaces workflow monitor. Monitor execution of a workflow from the command line.

positional arguments:
  log_path              path to the workflow's HTCondor log
  workflow_request_id   ID of the workflow request that ran the workflow
  is_dag                is the workflow to be monitored a DAG workflow?

options:
  -h, --help            show this help message and exit
  -P PROFILE, --profile PROFILE
                        profile name to use; e.g. test, production; DEFAULT: dsoc-dev
```

## Contents
This package contains the following directories and files:

- [wf_monitor](wf_monitor)
  - Contains the Python scripts for this package.
  - [monitor.py](wf_monitor/monitor.py)
    - Contains the core functionality of this package.
  - [enum.py](wf_monitor/enum.py)
    - Contains enum classes used in `monitor.py`.
  - [\_\_init__.py](wf_monitor/__init__.py)
    - Contains a license, a docstring, and the package version.
- [test](test)
  - Contains the tests for this package.
  - [test_monitor.py](test/test_monitor.py)
    - Contains the tests for `monitor.py`.
  - [test_enum.py](test/test_enum.py)
    - Contains the tests for `enum.py`
- `README.md`
  - Overall documentation on this package.
- [LICENSE](LICENSE)
  - The GNU General Public License, Version 3.
- [poetry.lock](poetry.lock)
  - The auto-generated file made by a package and dependency manager, Poetry.
- [pyproject.toml](pyproject.toml)
  - The package configuration file.

## How to Run Tests
1. Bring up the `docker compose` stack.
2. Open a terminal in a container.
   1. The workflow container is the only one that has been tried successfully so far.
3. Install `wf_monitor` using pip.
   1. One way: `cd ../../apps/cli/utilities/wf_monitor; poetry install --with test`
4. Run the tests.
   1. `poetry run pytest . --cov=wf_monitor --cov-report term-missing`.
      1. If you don't want the coverage report, drop everything starting with `--cov`.
