/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import {Component, OnInit, Input, SimpleChanges} from '@angular/core';
import { NgbModal } from "@ng-bootstrap/ng-bootstrap";
import { ProductMetadata } from 'src/app/workspaces/model/archive-models';

@Component({
  selector: 'app-proposal-info',
  templateUrl: './proposal-info.component.html',
  styleUrls: ['./proposal-info.component.scss']
})
export class ProposalInfoComponent implements OnInit {
  @Input() set productMetadata(productMetadata: ProductMetadata) {
    if (productMetadata) {
      this.title = productMetadata.title;
      this.abstract = productMetadata.abstract;
      this.observing_types = productMetadata.observing_types;
      this.project_code = productMetadata.project_code;
    }
  }

  @Input() set inputSdmId(sdmId: string) {
    if (sdmId) {
      this.sdmId = sdmId;
    }
  }

  public title: string;
  public abstract: string;
  public observing_types: Array<string>;
  public project_code: string;
  public sdmId: string;
  public missingProposalInfoMessage: string;

  constructor(
    private modalService: NgbModal,
  ) { }

  public open(content) {
    this.modalService.open(content, { ariaLabelledBy: "modal-title", scrollable: true });
    // NgbModal prohibits the body from scrolling by default.
    // Prevent that here so that DAs can see all the other data on the page while the modal is open
    document.body.style.overflow = "inherit";
  }

  public canDisplayProposalInformation(): boolean {
    // we can have empty titles and/or abstracts, but we definitely shouldn't ever have a missing project code
    return (
      this.title !== undefined && this.abstract !== undefined && (this.project_code !== undefined && this.project_code.length > 0)
    );
  }

  ngOnInit(): void {}

  ngOnChanges(changes: SimpleChanges): void {
    this.missingProposalInfoMessage = !this.canDisplayProposalInformation()
      ? `Unable to retrieve proposal information for product: ${this.sdmId}`
      : "";
  }
}
