import { Component, OnInit } from '@angular/core';
import {SettingsService} from "../../services/settings.service";
import {ProcessingSettings} from "../../model/processing-settings";
import {CapabilitiesService} from "../../services/capabilities.service";

@Component({
  selector: 'app-default-settings',
  templateUrl: './default-settings.component.html',
  styleUrls: ['./default-settings.component.scss']
})
export class DefaultSettingsComponent implements OnInit {

  enabledStandardCapabilities: string[]
  allSettings: ProcessingSettings
  defaultCapability: string
  autoSubmitStatus: string

  constructor(private settingsService: SettingsService, private capabilitiesService: CapabilitiesService) {

  }

  ngOnInit() {
    const settingsObserver = {
      next: (settings) => {
        this.allSettings = settings
        this.defaultCapability = settings.default_capability
        this.autoSubmitStatus = settings.auto_submit_status
      },
      error: (error) => console.error("Error retrieving processing settings: ", error)
    };
    this.settingsService.getProcessingSettings().subscribe(settingsObserver)

    // get list of enabled capabilities
    const enabledCapabilitiesObserver = {
      next: (capabilities) => {
        this.enabledStandardCapabilities = capabilities['enabled_capabilities']
          .filter(function (str) {return str.startsWith('std') && (!str.includes('cms') && !str.includes('restore'));});
      },
      error: (error) => console.error("Error when retrieving enabled capabilities:", error),
    };
    this.capabilitiesService.getEnabledCapabilities().subscribe(enabledCapabilitiesObserver);


  }

  updateDefaultSettings(settingName: string, newState: string){
    let key: string
    let changed: boolean
    let parameters;
    switch (settingName){
      case 'defaultCapability':
        key = "default_capability";
        changed = (newState !== this.defaultCapability)
        break;
      case "autoSubmitStatus":
        key = 'auto_submit_status';
        changed = (newState !== this.autoSubmitStatus)
        break;
      default:
        key = 'not found';
    }

    if (key !== "not found" && changed) {
      parameters = {
        [key]: newState
      }
      const settingUpdateObserver = {
        next: (settings: ProcessingSettings) => {
          this.allSettings = settings;
          this.autoSubmitStatus = settings.auto_submit_status;
          this.defaultCapability = settings.default_capability;
          // reload settings page to show updated results
          window.location.reload();
        },
        error: (error) => {
          console.log(error);
        }
      };
      this.settingsService.updateProcessingSettings(parameters).subscribe(settingUpdateObserver);
    } else {
      console.error("No settings found matching " + settingName + ". Unable to update.")
    }
  }
}
