/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { Injectable } from "@angular/core";
import { HttpClient } from "@angular/common/http";
import { Observable } from "rxjs";
import { Capability } from "../model/capability";

@Injectable({
  providedIn: "root",
})
export class DataRetrieverService {
  constructor(private httpClient: HttpClient) {}

  /**
   * Gets JSON representation of a capability given a name
   * @param name  The name of the capability
   */
  getCapability(name: string): Observable<Capability> {
    const url = `capability/${name}`;
    return this.httpClient.get<Capability>(url);
  }

  /**
   * Gets URL of a capability given a name for polling
   * @param name  The name of the capability
   */
  getCapabilityUrl(name: string): string {
    return  `capability/${name}`;
  }

  /**
   * Gets URL of a capability given a name for polling
   * @param name  The name of the capability
   * @param pauseAction The pause action to set
   */
  togglePauseCapability(name: string, pauseAction: string): Observable<any> {
    const url = `capability/${name}/${pauseAction}`;
    return this.httpClient.post<any>(url, JSON.stringify({'name': name}));
  }
}
