/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import {NgModule} from "@angular/core";
import {CommonModule} from "@angular/common";
import {NgbModule} from "@ng-bootstrap/ng-bootstrap";
import {WorkspacesRoutingModule} from "./workspaces-routing.module";
import {WorkspacesComponent} from "./workspaces.component";
import {FormsModule, ReactiveFormsModule} from "@angular/forms";
import {CapabilityRequestComponent} from "./components/capability-request/capability-request.component";
import {RequestHeaderComponent} from "./components/capability-request/components/request-header/request-header.component";
import {ParametersComponent} from "./components/capability-request/components/parameters/parameters.component";
import {CreateNewVersionFormComponent} from "./components/capability-request/components/create-new-version-form/create-new-version-form.component";
import {StatusBadgeComponent} from "./components/capability-request/components/status-badges/status-badge.component";
import {ActiveCapabilityRequestsComponent} from "./components/active-capability-requests/active-capability-requests.component";
import {FilesComponent} from "./components/capability-request/components/files/files.component";
import {RequestOperationsComponent} from "./components/capability-request/components/request-operations/request-operations.component";
import {MetadataComponent} from './components/capability-request/components/metadata/metadata.component';
import {CapabilityLaunchForObservationComponent} from "./components/active-capability-requests/components/capability-launch-for-observation/capability-launch-for-observation.component";
import {VersionsComponent} from "./components/capability-request/components/versions/versions.component";
import {EmailTemplatesComponent} from './components/email-templates/email-templates.component';
import {TemplateCardsComponent} from './components/email-templates/components/template-cards/template-cards.component';
import {EditorComponent} from './components/editor/editor.component';
import {FilterMenuComponent} from './components/active-capability-requests/components/filter-menu/filter-menu.component';
import {QaControlsComponent} from './components/capability-request/components/qa-controls/qa-controls.component';
import {SendEmailComponent} from './components/send-email/send-email.component';
import {CapabilityDataAccessComponent} from "./components/capability-request/components/capability-data-access/capability-data-access.component";
import {InternalNotesComponent} from './components/capability-request/components/internal-notes/internal-notes.component';
import { ProposalInfoComponent } from './components/capability-request/components/proposal-info/proposal-info.component'
import {WsHeaderComponent} from './ws-header/ws-header.component';
import {WsHomeComponent} from './ws-home/ws-home.component';
import {MatAutocompleteModule} from '@angular/material/autocomplete';
import {MatFormFieldModule} from '@angular/material/form-field';
import {MatSelectModule} from '@angular/material/select';
import {MatInputModule} from '@angular/material/input';
import {MatPaginatorModule} from '@angular/material/paginator';
import { NgbModalDraggableModule } from "../shared/ngb-modal-draggable/ngb-modal-draggable.module";
import { DefaultSettingsComponent } from './components/default-settings/default-settings.component';

@NgModule({
  declarations: [
    WorkspacesComponent,
    CapabilityRequestComponent,
    ProposalInfoComponent,
    RequestHeaderComponent,
    StatusBadgeComponent,
    ParametersComponent,
    CreateNewVersionFormComponent,
    ActiveCapabilityRequestsComponent,
    FilesComponent,
    RequestOperationsComponent,
    MetadataComponent,
    CapabilityLaunchForObservationComponent,
    VersionsComponent,
    EmailTemplatesComponent,
    TemplateCardsComponent,
    EditorComponent,
    FilterMenuComponent,
    QaControlsComponent,
    SendEmailComponent,
    CapabilityDataAccessComponent,
    InternalNotesComponent,
    WsHeaderComponent,
    WsHomeComponent,
    DefaultSettingsComponent,
],
  imports: [
    CommonModule,
    NgbModule,
    NgbModalDraggableModule,
    WorkspacesRoutingModule,
    ReactiveFormsModule,
    FormsModule,
    MatAutocompleteModule,
    MatFormFieldModule,
    MatSelectModule,
    MatInputModule,
    MatPaginatorModule,
  ],
})
export class WorkspacesModule {}
