# Data Annotator
The data annotator utility is used to add, edit, or remove helpful information to products in the AAT database. It
currently has two main uses: adjusting data quality notes on science products and adjusting data acknowledgements on
projects. The data annotator allows for several different search terms, but will prompt the user for any data that is
necessary for its run.

### General Usage
```
usage:
data_annotator (notes | project-acks | ack-text) [-h] --action-flag action --search-flags search_terms --optional-flags extras

subcommands:
    notes                 Run the data quality notes mode to create, edit, or remove data quality notes from science products.
    ack-text              Run the acknowledgement text mode to create, edit, or remove acknowledgements from the database.
    project-acks          Run the project acknowledgements mode to assign or remove data acknowledgements from projects.
    -h, --help            Show a help message for the top-level data annotator and exit.
```

### Data Quality Notes Mode
The data quality notes mode is intended for use by data analysts for giving feedback on the quality and status of
either individual entries or ranges of data in the Archive. It can handle creation, modification, and deletion of data
quality notes on either individual entries or ranges of data determined by the passed in search options. When modifying
or deleting data quality notes, the old comment text, problem severity, and problem type must all match the desired
data quality note entry.

```
usage:
data_annotator notes [-h] (-c | -m | -d) [--project-code PROJECT_CODE] [--date-range DATE_RANGE DATE_RANGE] [--external-name EXTERNAL_NAME] [--configuration CONFIGURATION]
    [--band BAND] [--comment COMMENT] [--old-comment OLD_COMMENT] [--problem-severity PROBLEM_SEVERITY] [--problem-type PROBLEM_TYPE]

action flags, exactly one required:
    -c, --create          Create a comment for one or more datasets. Cannot be used with -d/--delete or -m/--modify.
    -m, --modify          Modify a comment for one or more datasets. Cannot be used with -d/--delete or -c/--create.
    -d, --delete          Delete a comment for one or more datasets. Cannot be used with -c/--create or -m/--modify.
    -h, --help            Show a help message for the data quality notes mode and exit.

search flags:
    --project-code PROJECT_CODE
            A string representing the project code to search by.
    --date-range DATE_RANGE DATE_RANGE
            Two strings representing beginning and end date to search by.
    --external-name EXTERNAL_NAME
            A string representing the external name to search by
    --configuration CONFIGURATION
            A string representing the configuration to search by.
    --band BAND
            A string representing the band to search by.
    --comment "COMMENT"
            A string representing the comment to add. The text must be wrapped in quotation marks.
    --old-comment "OLD_COMMENT"
            A string representing the old comment to search by. Only used with -m/--modify. The text must be wrapped in quotation marks.
    --problem-severity PROBLEM_SEVERITY
            An integer between 0-3 with 0 being not a problem, and 1-3 being low, medium and high severity.
    --problem-type PROBLEM_TYPE
            An integer from 1-10; 1. Comment/Other, 2. Clock Error, 3. Position Error, 4. Model Error, 5. Observing Error, 6. Hardware Error, 7. Session ID, 8. Data Errors, 9. Missing Data, 10. Processing Error.
```

### Acknowledgement Text Mode
The acknowledgement text mode is intended for use by data analysts for adding, modifying, or deleting acknowledgements
available for project assignment. An acknowledgement must exist before it can be assigned to a project, and no projects
must use an acknowledgement before it can be deleted.
```
usage:
data_annotator ack-text [-h] (-c | -m | -d) [--acknowledgement-id ACKNOWLEDGEMENT_ID] [--institution INSTITUTION] [--text TEXT]

action flags, exactly one required:
    -c, --create          Create an acknowledgement. Cannot be used with -d/--delete or -m/--modify.
    -m, --modify          Modify an acknowledgement's text. Cannot be used with -d/--delete or -c/--create.
    -d, --delete          Delete an acknowledgement. Cannot be used with -c/--create or -m/--modify.
    -h, --help            Show a help message for the acknowledgement text mode and exit.

search flags:
    --acknowledgement-id ACKNOWLEDGEMENT_ID
            An integer representing the acknowledgement to use.
    --institution INSTITUTION
            A string representing the institution (e.g. ALMA, NRAO) to associate with an acknowledgement.
    --text TEXT
            A string representing the acknowledgement text to add when creating an acknowledgement, or change to when modifying an acknowledgement. The text must be wrapped in quotation marks.
```

### Project Acknowledgements Mode
The project acknowledgements mode is intended for use by data analysts for assigning or deleting acknowledgements for
individual projects.
```
usage:
data_annotator project-acks [-h] (-a | -d) [--project-code PROJECT_CODE] [--acknowledgement-id ACKNOWLEDGEMENT_ID]

action flags, exactly one required:
    -a, --assign          Assign an acknowledgement to a project. Cannot be used with -d/--delete.
    -d, --delete          Delete an acknowledgement from a project. Cannot be used with -a/--assign.
    -h, --help            Show a help message for the project acknowledgements mode and exit.

search flags:
    --acknowledgement-id ACKNOWLEDGEMENT_ID
            An integer representing the acknowledgement to use.
    --project-code PROJECT_CODE
            A string representing the project code to associate with the acknowledgement.
```

## Examples
<b>Help Examples:</b>

Show the top-level data annotator help message:

`data_annotator -h`

Show the data annotator help message for the data quality notes mode:

`data_annotator notes -h`

---
<b>Data Quality Notes Mode Examples:</b>

Create a data quality note on the image with the SDM ID "VLBA_DQ2329_dq2329_BIN0_SRC0_15_230831T142322.idifits" that indicates bad weather:

`data_annotator notes -c --external-name "VLBA_DQ2329_dq2329_BIN0_SRC0_15_230831T142322.idifits" --comment "I am a comment indicating bad weather during the observation process." --problem-severity 3 --problem-type 1`

Modify the above data quality note to indicate high levels of fog specifically:

`data_annotator notes -m --external-name "VLBA_DQ2329_dq2329_BIN0_SRC0_15_230831T142322.idifits" --old-comment "I am a comment indicating bad weather during the observation process." --comment "I am a comment indicating fog isntead."  --problem-severity 3 --problem-type 1`

Delete the above data quality note:
`data_annotator notes -d --external-name "VLBA_DQ2329_dq2329_BIN0_SRC0_15_230831T142322.idifits" --comment "I am a comment indicating fog isntead."  --problem-severity 3 --problem-type 1`

Create a data quality note on all science products associated with project 22A-444 that indicates a project wide issue:
`data_annotator notes -c --project-code 22A-444 --comment "All products for this project were created on a faulty server."  --problem-severity 1 --problem-type 6`

---
<b>Acknowledgement Text Mode Examples:</b>

Create an acknowledgement for an institution thanking them for use of their totally real telescopes:

`data_annotator ack-text -c --institution TEST --text "Thank you to the Totally Existing Space Telescopes (TEST) Facility for use of there totally real telescopes."`

Modify the above acknowledgement to include more thanks.
`data_annotator ack-text -m --institution TEST --text "Thank you to the Totally Existing Space Telescopes (TEST) Facility for use of there totally real telescopes. This project would not have been possible without their generous, and totally real support."`

Delete the above acknowledgement, allowing the data annotator to prompt for the acknowledgement id.
`data_annotator ack-text -d`

---
<b>Project Acknowledgements Mode Examples:</b>

Assign acknowledgement #23 to project 22A-444:

`data_annotator project-acks -a --project-code 22A-444 --acknowledgement-id 23`

Unassign acknowledgement #23 from project 22A-444:

`data_annotator project-acks -d --project-code 22A-444 --acknowledgement-id 23`
