# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""
    Tests (locally) the creation, adding a file for, and
    the submission of a std_calibration_and_imaging workflow.
"""
#
# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
import requests

TIMEOUT = 30
SERVICE_URL = "http://localhost:3457"  # From docker.properties; but modified to access localhost
EMAIL = ""  # Add your email for testing


def create_and_submit_capability_request(capability: str, params: dict = None):
    """
    Calls the REST endpoint to create and submit a capability request in Workspaces.

    :param capability: The capability name to submit.
    :param params: Parameters necessary to run the capability.
    """

    print(f"Sending create and submit capability request for {capability} with params: {params}")
    url = f"{SERVICE_URL}/capability/{capability}/request/create-and-submit"
    response = requests.post(url, json=params, timeout=TIMEOUT)
    response_content = response.json()
    capability_request_id = response_content["capability_request_id"]

    print(f"\t{response_content}")
    print(f"\t{response.ok=}")
    print(f"{response.status_code}")
    print(f"\t{capability_request_id=}")


def test_create_and_submit_capability_request():
    """
    Tests creation and submitting of a 'std_calibration_and_imaging' capability request.
    """
    product_locator = "uid://evla/execblock/dd42ec9d-1a6c-4441-b25a-fd0dd35d3a82"
    capability_request_params = {"parameters": {"user_email": EMAIL, "product_locator": product_locator}}

    create_and_submit_capability_request("std_calibration_and_imaging", capability_request_params)


def main():
    """
    Calls functions that test the 'std_calibration_and_imaging' workflow.
    """
    test_create_and_submit_capability_request()


if __name__ == "__main__":
    main()
