# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""
    Tests (locally) the creation, adding a file for, and
    the submission of a std_calibration_and_imaging workflow.
"""
#
# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
import json

import requests

TIMEOUT = 30
SERVICE_URL = "http://localhost:3456"  # From docker.properties; but modified to access localhost
EMAIL = ""  # Put your email here for testing


def create_and_submit_workflow_request(workflow: str, params: dict = None):
    """
    Calls the REST endpoint to create and submit a workflow request in Workspaces.

    :param workflow: The workflow name to submit.
    :param params: Parameters necessary to run the workflow.
    """

    print(f"Sending create workflow request for {workflow} with params: {params}")
    url = f"{SERVICE_URL}/workflows/{workflow}/requests/create"
    response = requests.post(url, json=params, timeout=TIMEOUT)
    print(f"\t{response.content}")
    print(f"\t{response.ok=}")
    response_content = json.loads(response.content.decode())
    workflow_request_id = response_content["workflow_request_id"]
    print(f"\t{workflow_request_id=}")

    print(f"\nSending add file request for {workflow} with an ID of {workflow_request_id}")
    url = f"{SERVICE_URL}/workflows/{workflow}/requests/{workflow_request_id}/files/PPR.xml"
    with open("std_calibration_and_imaging_PPR.xml", "r", encoding="utf8") as ppr_file:
        ppr_content = ppr_file.read()
    response = requests.put(url, data=ppr_content, timeout=TIMEOUT)
    print(response.content)
    print(f"{response.status_code=}")
    print(f"\t{response.ok=}")

    print(f"\nSending submit workflow request for {workflow} with an ID of {workflow_request_id}")
    url = f"{SERVICE_URL}/workflows/{workflow}/requests/{workflow_request_id}/submit"
    response = requests.post(url, timeout=TIMEOUT)
    print(f"{response.content}")
    print(f"{response.status_code}")
    print(f"\t{response.ok=}")


def test_create_and_submit_workflow_request():
    """
    Tests creation and submitting of a 'std_calibration_and_imaging' workflow request.
    """
    product_locator = "uid://evla/execblock/dd42ec9d-1a6c-4441-b25a-fd0dd35d3a82"
    wf_request_params = {
        "metadata": {},
        "user_email": EMAIL,
        "provided_files": [],
        "product_locator": product_locator,
        "files_to_transfer": "",
        "need_project_metadata": True,
    }

    create_and_submit_workflow_request("std_calibration_and_imaging", wf_request_params)


def main():
    """
    Calls functions that test the 'std_calibration_and_imaging' workflow.
    """
    test_create_and_submit_workflow_request()


if __name__ == "__main__":
    main()
