# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""Allowing VLASS coarse cubes to be viewed in CARTA

Revision ID: 09db63733787
Revises: ae1073977835
Create Date: 2024-12-23 10:20:51.881935

"""
from pathlib import Path

import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "09db63733787"
down_revision = "ae1073977835"
branch_labels = None
depends_on = None


def get_template_content(dir_name: str, file_name: str) -> str:
    return (Path.cwd() / "versions" / "templates" / dir_name / file_name).read_text()


# Workflow templates that need to be updated
# Format: [workflow name, filename, old template content, new template content]
carta_sh_workflow_templates = [
    [
        "carta-debug",
        "carta.sh",
        bytes(get_template_content("carta-debug", "sh_2.8.6.txt"), "utf-8"),
        bytes(get_template_content("carta-debug", "sh_2.8.7.txt"), "utf-8"),
    ],
    [
        "carta",
        "carta.sh",
        bytes(get_template_content("carta", "sh_2.8.6.txt"), "utf-8"),
        bytes(get_template_content("carta", "sh_2.8.7.txt"), "utf-8"),
    ],
]


def upgrade():
    conn = op.get_bind()
    for template_list in carta_sh_workflow_templates:
        conn.execute(
            f"""
            UPDATE workflow_templates
            SET content=%s WHERE filename=%s
            AND workflow_name=%s
            """,
            template_list[3],
            template_list[1],
            template_list[0],
        )


def downgrade():
    conn = op.get_bind()
    for template_list in carta_sh_workflow_templates:
        conn.execute(
            f"""
        UPDATE workflow_templates
        SET content=%s WHERE filename=%s
        AND workflow_name=%s
        """,
            template_list[2],
            template_list[1],
            template_list[0],
        )
