# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""Add CapabilityProducts

Revision ID: 0eaeef98b400
Revises: 44d35e7c3300
Create Date: 2024-09-10 15:47:31.294333

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "0eaeef98b400"
down_revision = "44d35e7c3300"
branch_labels = None
depends_on = None


def upgrade():
    op.create_table(
        "capability_product_names",
        sa.Column("product_name", sa.String, primary_key=True),
        comment="An enumeration of ingestable products",
    )
    op.create_table(
        "capability_products",
        # Include a "serial" primary key since this record has data in addition to the association between product_names and capabilities
        sa.Column("capability_product_id", sa.Integer, primary_key=True, autoincrement=True),
        sa.Column("capability_name", sa.String, sa.ForeignKey("capabilities.capability_name"), nullable=False),
        sa.Column("product_name", sa.String, sa.ForeignKey("capability_product_names.product_name"), nullable=False),
        sa.Column("is_included_in_partial_pass", sa.Boolean, server_default="True"),
        comment="An enumeration of the ingestable products that can be produced by each capability",
    )
    op.create_unique_constraint(None, "capability_products", ["capability_name", "product_name"])
    op.execute("""INSERT INTO capability_product_names VALUES ('calibration'), ('image'), ('execution_block')""")
    op.execute(
        """INSERT INTO capability_products (capability_name, product_name, is_included_in_partial_pass) VALUES
        ('std_calibration', 'calibration', true),
        ('std_cms_imaging', 'image', true),
        ('std_restore_imaging', 'image', true),
        ('std_calibration_and_imaging', 'calibration', true),
        ('std_calibration_and_imaging', 'image', false)
    """
    )


def downgrade():
    op.drop_table("capability_products", if_exists=True)
    op.drop_table("capability_product_names", if_exists=True)
