# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""add cal and img entries needed for PPR

Revision ID: 30a155c9bb19
Revises: 7ba77453966a
Create Date: 2024-10-24 13:39:18.227380

"""
from pathlib import Path

import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "30a155c9bb19"
down_revision = "7ba77453966a"
branch_labels = None
depends_on = None
wf_name = "std_calibration_and_imaging"


def upgrade():
    conn = op.get_bind()

    # Add the std_calibration_and_imaging entries to the casa_matrix_capabilities table
    conn.execute(
        f"""
        INSERT INTO casa_matrix_capabilities (capability_name, matrix_id)
            SELECT '{wf_name}', matrix_id
            FROM casa_matrix_casa_versions
            WHERE casa_version in
            ('casa-6.4.1-12-pipeline-2022.2.0.64',
             'casa-6.4.1-12-pipeline-2022.2.0.68',
             'casa-6.5.3-28-pipeline-2023.0.0.36',
             'casa-6.5.4-9-pipeline-2023.1.0.124',
             'casa-6.5.4-9-pipeline-2023.1.0.125',
             'casa-6.6.1-17-pipeline-2024.1.0.8');
    """
    )

    # Modify the capabilities table to point to actual files/casa directories for std_calibration_and_imaging
    conn.execute(
        f"""
        UPDATE capabilities
        SET casa_recipe = 'procedure_hifv_calimage_cont_selfcal.xml', default_casa_capo_key = 'homeForReprocessing'
        WHERE capability_name = '{wf_name}'
    """
    )


def downgrade():
    op.execute(
        f"""
        DELETE FROM casa_matrix_capabilities
        WHERE capability_name = E'{wf_name}'
    """
    )

    op.execute(
        f"""
        UPDATE capabilities
        SET casa_recipe = NULL, default_casa_capo_key = NULL
        WHERE capability_name = '{wf_name}'
    """
    )
