# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""std calibration and imaging workflow

Revision ID: 44041d0425b7
Revises: 0eaeef98b400
Create Date: 2024-09-11 10:16:39.379118

"""
from pathlib import Path

import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "44041d0425b7"
down_revision = "0eaeef98b400"
branch_labels = None
depends_on = None

wf_name = "std_calibration_and_imaging"


def set_content(filename: str) -> str:
    return (Path.cwd() / "versions" / "templates" / wf_name / filename).read_text()


def upgrade():
    conn = op.get_bind()

    op.execute(
        f"""
        INSERT INTO workflows (workflow_name, uses_casa, requires_lustre, remote_capable, external_wf)
        VALUES (E'{wf_name}', true, true, false, false)
        """
    )

    conn.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES (%s, %s, E'{wf_name}')
        """,
        wf_name + "_fetch.condor",
        set_content("fetch_condor_2.8.6.txt"),
    )

    conn.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES (%s, %s, E'{wf_name}')
        """,
        wf_name + "_fetch.sh",
        set_content("fetch_sh_2.8.6.txt"),
    )

    conn.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES (%s, %s, E'{wf_name}')
        """,
        wf_name + "_envoy.condor",
        set_content("envoy_condor_2.8.6.txt"),
    )

    conn.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES (%s, %s, E'{wf_name}')
        """,
        wf_name + "_envoy.sh",
        set_content("envoy_sh_2.8.6.txt"),
    )

    conn.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES (%s, %s, E'{wf_name}')
        """,
        wf_name + "_convey.condor",
        set_content("convey_condor_2.8.6.txt"),
    )

    conn.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES (%s, %s, E'{wf_name}')
        """,
        wf_name + "_convey.sh",
        set_content("convey_sh_2.8.6.txt"),
    )

    conn.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES (%s, %s, E'{wf_name}')
        """,
        wf_name + ".dag",
        set_content("dag_2.8.6.txt"),
    )

    conn.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES (%s, %s, E'{wf_name}')
        """,
        "metadata.json",
        set_content("metadata_2.8.6.txt"),
    )


def downgrade():
    op.execute(
        f"""
        DELETE FROM workflow_templates
        WHERE workflow_name = E'{wf_name}'
        """
    )

    op.execute(
        f"""
        DELETE FROM workflows
        WHERE workflow_name = E'{wf_name}'
        """
    )
