# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""Add std_calibration_and_imaging Capability

Revision ID: 44d35e7c3300
Revises: 351f55781006
Create Date: 2024-09-12 13:22:29.288949

"""
from pathlib import Path

from alembic import op

# revision identifiers, used by Alembic.
revision = "44d35e7c3300"
down_revision = "351f55781006"
branch_labels = None
depends_on = None


def get_template_content(dir: str, filename: str) -> str:
    return (Path.cwd() / "versions" / "templates" / dir / filename).read_text()


def upgrade():
    conn = op.get_bind()

    op.execute(
        """INSERT INTO capabilities (max_jobs, capability_name, has_image_products, requires_qa, casa_recipe, default_casa_capo_key) VALUES (50, 'std_calibration_and_imaging', true, true, 'procedure_hifv_calimage_cont_cube_selfcal.xml', 'homeForReprocessing')"""
    )
    op.execute(
        """INSERT INTO capability_state_machines (capability_name, machine_type, associated_workflows) VALUES ('std_calibration_and_imaging', 'double_qa_partial_pass', '{"workflow_name": "std_calibration_and_imaging"}')"""
    )

    std_cal_img_ppr = get_template_content("std_calibration_and_imaging", "PPR_2.8.6.xml")

    conn.execute(
        """INSERT INTO capability_templates (filename, content, capability_name)
           VALUES ('PPR.xml', %s, 'std_calibration_and_imaging')""",
        std_cal_img_ppr,
    )

    # Add notification template for completion
    template_content = get_template_content(
        "emails", "std_calibration_and_imaging_complete_both.txt"
    ).rstrip() + get_template_content("emails", "std_calibration_and_imaging_complete_calonly.txt")

    conn.execute(
        """
        INSERT INTO notification_templates (name, description, template)
        VALUES ('std_calibration_and_imaging_complete',
        'Email template for notifying PI/CoI that a std_calibration_and_imaging capability is complete',
        %s)
        """,
        template_content,
    )


def downgrade():
    op.execute(
        f"""
        DELETE FROM notification_templates
        WHERE name='std_calibration_and_imaging_complete'
        """
    )

    op.execute(
        f"""
        DELETE FROM capability_state_machines
        WHERE capability_name = 'std_calibration_and_imaging'
        """
    )

    op.execute(
        """
        DELETE FROM capability_state_actions
        WHERE transition_id in (
        SELECT transition_id
        FROM capability_state_transitions
        WHERE capability_name ='std_calibration_and_imaging'
        )
        """
    )

    op.execute(
        """
        DELETE FROM capability_state_transitions
        WHERE capability_name='std_calibration_and_imaging'
        """
    )

    op.execute(
        """
        DELETE FROM capability_states
        WHERE capability_name='std_calibration_and_imaging'
        """
    )

    op.execute(
        """
        DELETE FROM capability_templates
        WHERE capability_name='std_calibration_and_imaging'
        """
    )

    op.execute(
        f"""
        DELETE FROM capabilities
        WHERE capability_name = 'std_calibration_and_imaging'
        """
    )
