# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""Add flatten flag to download.sh template

Revision ID: 486da51bb6ff
Revises: 09db63733787
Create Date: 2025-01-13 09:43:10.619404

"""
from pathlib import Path

import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "486da51bb6ff"
down_revision = "09db63733787"
branch_labels = None
depends_on = None

new_download_sh = "download_2.8.7.txt"
old_download_sh = "download_2.8.1.txt"


def get_template_content(file_name: str) -> str:
    return (Path.cwd() / "versions" / "templates" / "downloads" / file_name).read_text()


def upgrade():
    conn = op.get_bind()
    conn.execute(
        """
        UPDATE workflow_templates
        SET content=%s WHERE filename='download.sh'
        AND workflow_name='download'
        """,
        get_template_content(new_download_sh),
    )


def downgrade():
    conn = op.get_bind()
    conn.execute(
        """
        UPDATE workflow_templates
        SET content=%s WHERE filename='download.sh'
        AND workflow_name='download'
        """,
        get_template_content(old_download_sh),
    )
