# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""Add CapabilityRequest.controller_name

Revision ID: 528a9fb95936
Revises: 985ca1bdec62
Create Date: 2024-07-19 10:56:25.472430

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "528a9fb95936"
down_revision = "985ca1bdec62"
branch_labels = None
depends_on = None


def upgrade():
    op.add_column(
        "capability_requests",
        sa.Column(
            "controller_name",
            sa.String,
            sa.ForeignKey("processing_controllers.control_system"),
            comment="the system that initiated the capability request, almost always Workspaces (WS)",
        ),
    )
    op.execute("""UPDATE capability_requests SET controller_name = 'WS'""")
    op.alter_column("capability_requests", "controller_name", nullable=True)
    op.alter_column(
        "processing_controllers",
        "control_system",
        comment="A system capable of creating and submitting Workspaces Workflow or Capability Requests",
    )


def downgrade():
    op.drop_column("capability_requests", "controller_name")
    op.alter_column(
        "processing_controllers",
        "control_system",
        comment="A system capable of creating and submitting Workspaces Workflow Requests",
    )
