# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""email text encoding issue fix

Revision ID: 58690eec160b
Revises: 44041d0425b7
Create Date: 2024-09-23 07:38:07.364281

"""
from pathlib import Path

import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "58690eec160b"
down_revision = "44041d0425b7"
branch_labels = None
depends_on = None


def get_content(filename: str) -> str:
    return (Path.cwd() / "versions" / "templates" / "emails" / filename).read_text()


# Each element is the name of a notification template with similarly named files.
# E.g., for the "SAMPLE" notification template, the files should
# be named "SAMPLE_2.8.5.txt" and "SAMPLE_2.8.6.txt"
templates = [
    "carta_ready",
    "email",
    "entire_request_fail",
    "processing_custom_comments",
    "pims_notification",
    "std_calibration_complete",
    "std_cms_imaging_complete",
    "workflow_complete",
    "workflow_submitted",
    "ws_annihilator_failure",
    "ws_request_closed",
]


def upgrade():
    conn = op.get_bind()
    # Templates besides cal + imaging capability state machine
    for template_name in templates:
        conn.execute(
            """
            UPDATE notification_templates
            SET template=%s WHERE name=%s
            """,
            get_content(f"{template_name}_2.8.6.txt"),
            template_name,
        )


def downgrade():
    conn = op.get_bind()

    # Templates besides cal + imaging capability state machine
    for template_name in templates:
        conn.execute(
            """
            UPDATE notification_templates
            SET template=%s WHERE name=%s
            """,
            get_content(f"{template_name}_2.8.5.txt"),
            template_name,
        )
