# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""dynamic ppr procedures

Revision ID: 985ca1bdec62
Revises: 2b9f521c8fe2
Create Date: 2024-07-09 11:48:19.626089

"""
from pathlib import Path

import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "985ca1bdec62"
down_revision = "2b9f521c8fe2"
branch_labels = None
depends_on = None

ppr_name = "PPR.xml"
old_ppr = "ppr_2.8.4.txt"
new_ppr = "ppr_2.8.5.txt"


def set_content(capability: str, filename: str) -> bytes:
    return (Path.cwd() / "versions" / "templates" / capability / filename).read_text().encode()


def upgrade():
    conn = op.get_bind()

    # Add a default PPR for restore_basic_ms
    conn.execute(
        f"""
        INSERT INTO capability_templates (filename, content, capability_name)
        VALUES (E'{ppr_name}', %s, 'restore_basic_ms')
        """,
        set_content("restore_basic_ms", new_ppr)
    )

    # Update the default PPRs to have mustache tags capable of dynamically rendering procedures
    conn.execute(
        f"""
        UPDATE capability_templates
        SET content=%s
        WHERE filename=E'{ppr_name}' AND capability_name='std_calibration'
        """,
        set_content("std_calibration", new_ppr)
    )

    conn.execute(
        f"""
        UPDATE capability_templates
        SET content=%s
        WHERE filename=E'{ppr_name}' AND capability_name='restore_cms'
        """,
        set_content("restore_cms", new_ppr)
    )

    conn.execute(
        f"""
        UPDATE capability_templates
        SET content=%s
        WHERE filename=E'{ppr_name}' AND capability_name='std_restore_imaging'
        """,
        set_content("std_restore_imaging", new_ppr)
    )

    conn.execute(
        f"""
        UPDATE capability_templates
        SET content=%s
        WHERE filename=E'{ppr_name}' AND capability_name='std_cms_imaging'
        """,
        set_content("std_cms_imaging", new_ppr)
    )


def downgrade():
    conn = op.get_bind()

    conn.execute(
        f"""
        DELETE FROM capability_templates
        WHERE filename=E'{ppr_name}' AND capability_name='restore_basic_ms'
        """
    )

    conn.execute(
        f"""
        UPDATE capability_templates
        SET content=%s
        WHERE filename=E'{ppr_name}' AND capability_name='std_calibration'
        """,
        set_content("std_calibration", old_ppr)
    )

    conn.execute(
        f"""
        UPDATE capability_templates
        SET content=%s
        WHERE filename=E'{ppr_name}' AND capability_name='restore_cms'
        """,
        set_content("restore_cms", old_ppr)
    )

    conn.execute(
        f"""
        UPDATE capability_templates
        SET content=%s
        WHERE filename=E'{ppr_name}' AND capability_name='std_restore_imaging'
        """,
        set_content("std_restore_imaging", old_ppr)
    )

    conn.execute(
        f"""
        UPDATE capability_templates
        SET content=%s
        WHERE filename=E'{ppr_name}' AND capability_name='std_cms_imaging'
        """,
        set_content("std_cms_imaging", old_ppr)
    )
