"""add missing cal image capability templates

Revision ID: db4edca73cb8
Revises: f95cc49d9946
Create Date: 2025-01-06 09:19:57.085251

"""
from pathlib import Path

from alembic import op

# revision identifiers, used by Alembic.
from sqlalchemy.orm import Session

# This import can cause issues when trying to do a bare-bones
# alembic command for a fresh revision.   Let the import fail
# quietly, the import will work in the schema container
try:
    from workspaces.capability.schema import CapabilityTemplate
except ImportError:
    pass

# revision identifiers, used by Alembic.
revision = "db4edca73cb8"
down_revision = "f95cc49d9946"
branch_labels = None
depends_on = None

FILE_NAME = "flagtemplate_2.8.6.txt"
CAPABILITY_NAME = "std_calibration_and_imaging"


def get_content(capability: str, filename: str):
    return (Path.cwd() / "versions" / "templates" / capability / filename).read_text().encode("ascii")


def upgrade():
    session = Session(bind=op.get_bind())

    # add the templates
    flag = CapabilityTemplate(
        filename="flagtemplate.txt",
        content=get_content(CAPABILITY_NAME, FILE_NAME),
        capability_name=CAPABILITY_NAME,
    )
    session.add(flag)
    session.commit()


def downgrade():
    session = Session(bind=op.get_bind())
    file = (
        session.query(CapabilityTemplate)
        .filter_by(filename="flagtemplate.txt", capability_name=CAPABILITY_NAME)
        .one_or_none()
    )
    if file:
        session.delete(file)
        session.commit()
