# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""HTC 23 DAGs

Revision ID: df6ca1c4d778
Revises: 8d632a11a047
Create Date: 2024-11-06 12:29:26.258330

"""
from pathlib import Path

from alembic import op

# revision identifiers, used by Alembic.
revision = "df6ca1c4d778"
down_revision = "8d632a11a047"
branch_labels = None
depends_on = None

# List of workflows that need environment variables passed through the DAG to templates and don't have 2.8.6 migrations
workflows = [
    "null_dag",
    "pims_split",
    "std_calibration",
    "std_cms_imaging",
    "std_restore_imaging",
    "vlass_calibration",
    "vlass_coarse",
    "vlass_seci",
]
new_dag = "dag_2.8.6.txt"
old_dag = "dag_pre_2.8.6.txt"


def get_template_content(workflow: str, filename: str) -> str:
    return (Path.cwd() / "versions" / "templates" / workflow / filename).read_text()


def upgrade():
    conn = op.get_bind()

    # HTC 23 no longer allows DAGs to pass all the environment variables from the submit host to the node, they must now
    # be explicitly passed in the DAG
    for workflow in workflows:
        conn.execute(
            f"""
            UPDATE workflow_templates
            SET content=%s
            WHERE filename=E'{workflow}.dag' AND workflow_name=E'{workflow}'
            """,
            get_template_content(workflow, new_dag),
        )

    # Quicklook had a non-standard DAG filename
    workflow = "vlass_quicklook"
    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content=%s
        WHERE filename='vlass_ql.dag' AND workflow_name=E'{workflow}'
        """,
        get_template_content(workflow, new_dag),
    )


def downgrade():
    conn = op.get_bind()

    for workflow in workflows:
        conn.execute(
            f"""
            UPDATE workflow_templates
            SET content=%s
            WHERE filename=E'{workflow}.dag' AND workflow_name=E'{workflow}'
            """,
            get_template_content(workflow, old_dag),
        )

    workflow = "vlass_quicklook"
    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content=%s
        WHERE filename='vlass_ql.dag' AND workflow_name=E'{workflow}'
        """,
        get_template_content(workflow, old_dag),
    )
