"""update condor templates for HTC23

Revision ID: f95cc49d9946
Revises: df6ca1c4d778
Create Date: 2024-12-18 09:40:06.730214

"""
from pathlib import Path

from alembic import op

# revision identifiers, used by Alembic.
revision = "f95cc49d9946"
down_revision = "df6ca1c4d778"
branch_labels = None
depends_on = None

file_suffix = "condor_2.8.6.txt"


def get_content(workflow: str, filename: str):
    return (Path.cwd() / "versions" / "templates" / workflow / filename).read_text()


def upgrade():
    # update null - template under null_dag as that uses the same condor file
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{get_content("null_dag", file_suffix)}'
        WHERE filename='null.condor' AND workflow_name='null'
        """
    )
    # update pims_split
    for stage in ["split", "write_finished_file"]:
        file = stage + "_" + file_suffix
        template_name = stage + ".condor"
        op.execute(
            f"""
            UPDATE workflow_templates
            SET content=E'{get_content("pims_split", file)}'
            WHERE filename='{template_name}' AND workflow_name='pims_split'
            """
        )
    # update everything else
    stages = ["fetch", "envoy"]
    for wf in ["vlass_coarse", "vlass_quicklook", "vlass_seci", "restore_cms"]:
        if wf == "restore_cms":
            stages.append("deliver")
        for stage in stages:
            file = stage + "_" + file_suffix
            wf_name = "vlass_ql" if wf == "vlass_quicklook" else wf
            template_name = wf_name + "_" + stage + ".condor"
            op.execute(
                f"""
                    UPDATE workflow_templates
                    SET content=E'{get_content(wf, file)}'
                    WHERE filename='{template_name}' AND workflow_name='{wf}'
                    """
            )


def downgrade():
    # downgrade null - template under null_dag as that uses the same condor file
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{get_content("null_dag", 'condor_2.8.5.txt')}'
        WHERE filename='null.condor' AND workflow_name='null'
        """
    )

    # possible downgrade files endings
    down_suffix1 = file_suffix.replace("6", "3")
    down_suffix2 = file_suffix.replace("6", "5")
    down_suffix3 = file_suffix.replace("2.8.6", "pre_2.8.6")
    down_suffix4 = file_suffix.replace("6", "3.1")

    # update pims_split
    for stage in ["split", "write_finished_file"]:
        downgrade_suffix = down_suffix1 if stage == "split" else down_suffix3
        file = stage + "_" + downgrade_suffix
        template_name = stage + ".condor"
        op.execute(
            f"""
            UPDATE workflow_templates
            SET content=E'{get_content("pims_split", file)}'
            WHERE filename='{template_name}' AND workflow_name='pims_split'
            """
        )

    # downgrade restore_cms
    for stage in ["fetch", "envoy", "deliver"]:
        suffix = down_suffix2.replace("5", "5.1") if stage == "deliver" else down_suffix2
        file = stage + "_" + suffix
        template_name = "restore_cms_" + stage + ".condor"
        op.execute(
            f"""
            UPDATE workflow_templates
            SET content=E'{get_content("restore_cms", file)}'
            WHERE filename='{template_name}' AND workflow_name='restore_cms'
            """
        )

    stages = ["fetch", "envoy"]
    for wf in ["vlass_coarse", "vlass_quicklook", "vlass_seci"]:
        if wf == "vlass_seci":
            # this has a different file name
            stages.remove("fetch")
        for stage in stages:
            suffix = down_suffix4 if stage == "envoy" else down_suffix1
            file = stage + "_" + suffix
            wf_name = "vlass_ql" if wf == "vlass_quicklook" else wf
            template_name = wf_name + "_" + stage + ".condor"
            op.execute(
                f"""
                    UPDATE workflow_templates
                    SET content=E'{get_content(wf, file)}'
                    WHERE filename='{template_name}' AND workflow_name='{wf}'
                    """
            )
    # downgrade seci fetch
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{get_content("vlass_seci", "fetch_" + down_suffix3)}'
        WHERE filename='vlass_seci_fetch.condor' AND workflow_name='vlass_seci'
        """
    )
