# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""ingest vlass workflow

Revision ID: ffc3c74db716
Revises: df6ca1c4d778
Create Date: 2024-11-24 22:56:20.430326

"""
from pathlib import Path

from alembic import op

# revision identifiers, used by Alembic.
revision = "ffc3c74db716"
down_revision = "0670d1e6f1b4"
branch_labels = None
depends_on = None

wf_name = "ingest_vlass"


def set_content(filename: str) -> str:
    return (Path.cwd() / "versions" / "templates" / wf_name / filename).read_text()


def upgrade():
    conn = op.get_bind()

    op.execute(
        f"""
        INSERT INTO workflows (workflow_name, uses_casa, requires_lustre, remote_capable, external_wf) 
        VALUES (E'{wf_name}', false, true, false, true)
        ON CONFLICT DO NOTHING 
        """
    )

    conn.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES (%s, %s, %s)
            ON CONFLICT DO NOTHING 
        """,
        wf_name + ".condor",
        set_content("condor_2.8.7.txt"),
        wf_name,
    )

    conn.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES (%s, %s, %s)
            ON CONFLICT DO NOTHING 
        """,
        wf_name + ".sh",
        set_content("sh_2.8.7.txt"),
        wf_name,
    )

    conn.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES (%s, %s, %s)
            ON CONFLICT DO NOTHING 
        """,
        "aux_image_metadata.json",
        set_content("aux_image_metadata_2.8.7.txt"),
        wf_name,
    )


def downgrade():
    op.execute(
        f"""
        DELETE FROM workflow_templates WHERE workflow_name = E'{wf_name}'
        """
    )

    op.execute(
        f"""
        DELETE FROM workflows WHERE workflow_name = E'{wf_name}'
        """
    )
